@@ -1,4 +1,4 @@
-package At::Lexicon::app::bsky::unspecced 0.08 {
+package At::Lexicon::app::bsky::unspecced 0.09 {
     use v5.38;
     no warnings 'experimental::class', 'experimental::builtin';    # Be quiet.
     use feature 'class';
@@ -9,6 +9,7 @@ package At::Lexicon::app::bsky::unspecced 0.08 {
     class At::Lexicon::app::bsky::unspecced::skeletonSearchPost {
         field $uri : param;    # at-url, required
         ADJUST {
+            use URI;
             $uri = URI->new($uri) unless builtin::blessed $uri;
         }
 
@@ -33,6 +34,30 @@ package At::Lexicon::app::bsky::unspecced 0.08 {
             +{ uri => $did->_raw };
         }
     }
+
+    class At::Lexicon::app::bsky::unspecced::suggestion {
+        field $tag : param;            # string, required
+        field $subjectType : param;    # enum, required
+        field $subject : param;        # uri, required
+        ADJUST {
+            use URI;
+            use Carp;
+
+            # XXX: Lexicon says only 'actor' and 'feed' are know but service returns 'user'
+            Carp::confess 'unknown value for subjectType: ' . $subjectType
+                unless $subjectType eq 'actor' || $subjectType eq 'feed' || $subjectType eq 'user';
+            $subject = URI->new($subject) unless builtin::blessed $subject;
+        }
+
+        # perlclass does not have :reader yet
+        method tag         {$tag}
+        method subjectType {$subjectType}
+        method subject     {$subject}
+
+        method _raw() {
+            +{ tag => $tag, subjectType => $subjectType, subject => $subject->as_string };
+        }
+    }
 };
 1;
 __END__
